<?php

namespace Litecms\Commercialpackage\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Commercialpackage\Models\Commercialpackage;

class CommercialpackagePolicy
{

    /**
     * Determine if the given user can view the commercialpackage.
     *
     * @param UserPolicy $user
     * @param Commercialpackage $commercialpackage
     *
     * @return bool
     */
    public function view(UserPolicy $user, Commercialpackage $commercialpackage)
    {
        if ($user->canDo('commercialpackage.commercialpackage.view') && $user->isAdmin()) {
            return true;
        }

        return $commercialpackage->user_id == user_id() && $commercialpackage->user_type == user_type();
    }

    /**
     * Determine if the given user can create a commercialpackage.
     *
     * @param UserPolicy $user
     * @param Commercialpackage $commercialpackage
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('commercialpackage.commercialpackage.create');
    }

    /**
     * Determine if the given user can update the given commercialpackage.
     *
     * @param UserPolicy $user
     * @param Commercialpackage $commercialpackage
     *
     * @return bool
     */
    public function update(UserPolicy $user, Commercialpackage $commercialpackage)
    {
        if ($user->canDo('commercialpackage.commercialpackage.edit') && $user->isAdmin()) {
            return true;
        }

        return $commercialpackage->user_id == user_id() && $commercialpackage->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given commercialpackage.
     *
     * @param UserPolicy $user
     * @param Commercialpackage $commercialpackage
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Commercialpackage $commercialpackage)
    {
        return $commercialpackage->user_id == user_id() && $commercialpackage->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given commercialpackage.
     *
     * @param UserPolicy $user
     * @param Commercialpackage $commercialpackage
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Commercialpackage $commercialpackage)
    {
        if ($user->canDo('commercialpackage.commercialpackage.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given commercialpackage.
     *
     * @param UserPolicy $user
     * @param Commercialpackage $commercialpackage
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Commercialpackage $commercialpackage)
    {
        if ($user->canDo('commercialpackage.commercialpackage.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
